//--
//--    Copyright  1994,1995 Uluwatu Software.  All rights reserved.
//--
//--	Author:  Mark Salsbery (CIS 71603,3643)
//--
//-- 	Feel free to use this code any way you wish (at your own risk,
//--	  of course).
//--

#include <owl\owlpch.h>
#include <owl\point.h>
#include <owl\module.h>
#include <owl\window.h>
#include <owl\dialog.h>
#include <owl\gdiobjec.h>
#include <owl\button.h>
#include <owl\static.h>
#include <owl\opensave.h>
#include <bwcc.h>
#include "testapp.rh"
#include "opsavdlg.h"


DEFINE_RESPONSE_TABLE1(TCustomFileOpenDialog, TFileOpenDialog)
	EV_WM_CTLCOLOR,
END_RESPONSE_TABLE;



//--------------------------------------------------
//  TCustomFileOpenDialog::TCustomFileOpenDialog()
//--------------------------------------------------
TCustomFileOpenDialog::TCustomFileOpenDialog(TWindow *pParent,TData &data,
													   LPCSTR pTitle,
															 TModule *pMod) :
									TFileOpenDialog(pParent,data,
													IDD_OPENSAVE,pTitle,pMod)
{
	// get a brush for the list box backgrounds
	pBkBrush = new TBrush(::GetSysColor(COLOR_WINDOW));

	// get a TButton object for the help button
	pHelpButton = new TButton(this,IDHELP);

	// Init icon stuff
	try
	{
		pIcon = new TIcon(*GetApplication(),IDI_OWLAPP);
	}
	catch (...)
	{
		pIcon = 0;
	}
	pIconPlace = new TStatic(this,IDC_ST_ICONPLACE);
}


//---------------------------------------------------
//  TCustomFileOpenDialog::~TCustomFileOpenDialog()
//---------------------------------------------------
TCustomFileOpenDialog::~TCustomFileOpenDialog ()
{
	Destroy();

	delete pIcon;
	delete pBkBrush;
}


//----------------------------------------
//  TCustomFileOpenDialog::SetupWindow()
//----------------------------------------
void TCustomFileOpenDialog::SetupWindow()
{
	TRect WindowRect;
	int nXPos, nYPos;

	TFileOpenDialog::SetupWindow();

	// Hide Help button if necessary
	if (pHelpButton && !(Data.Flags & OFN_SHOWHELP))
	{
		pHelpButton->Show(SW_HIDE);
	}

	// Associate the icon with the Icon control
	if (pIcon)
		hOldIcon = (HICON)pIconPlace->SendMessage(STM_SETICON,
												   (WPARAM)(HICON)*pIcon,0L);
	// Center this window on the screen
	GetWindowRect(WindowRect);
	nXPos = (::GetSystemMetrics(SM_CXSCREEN) - WindowRect.Width()) / 2;
	nYPos = (::GetSystemMetrics(SM_CYSCREEN) - WindowRect.Height()) / 2;
	SetWindowPos(0,nXPos,nYPos,0,0,SWP_NOZORDER | SWP_NOSIZE);
}


//------------------------------------------
//  TCustomFileOpenDialog::CleanupWindow()
//------------------------------------------
void TCustomFileOpenDialog::CleanupWindow()
{
	// Restore the Icon control
	if (pIcon)
		pIconPlace->SendMessage(STM_SETICON,(WPARAM)hOldIcon,0L);

	TFileOpenDialog::CleanupWindow();
}


//---------------------------------------
//  TCustomFileOpenDialog::EvCtlColor()
//---------------------------------------
HBRUSH TCustomFileOpenDialog::EvCtlColor(HDC hDC,HWND hwndChild,UINT nCtlType)
{
	if (nCtlType == CTLCOLOR_LISTBOX)
		return *pBkBrush;
	else
		return TFileOpenDialog::EvCtlColor(hDC,hwndChild,nCtlType);
}



DEFINE_RESPONSE_TABLE1(TCustomFileSaveDialog, TFileSaveDialog)
	EV_WM_CTLCOLOR,
END_RESPONSE_TABLE;



//--------------------------------------------------
//  TCustomFileSaveDialog::TCustomFileSaveDialog()
//--------------------------------------------------
TCustomFileSaveDialog::TCustomFileSaveDialog(TWindow *pParent,TData &data,
														LPCSTR pTitle,
															 TModule *pMod) :
									TFileSaveDialog(pParent,data,
													IDD_OPENSAVE,pTitle,pMod)
{
	// get a brush for the list box backgrounds
	pBkBrush = new TBrush(::GetSysColor(COLOR_WINDOW));

	// get a TButton object for the help button
	pHelpButton = new TButton(this,IDHELP);

	// Init icon stuff
	try
	{
		pIcon = new TIcon(0,IDI_OWLAPP);
	}
	catch (...)
	{
		pIcon = 0;
	}
	pIconPlace = new TStatic(this,IDC_ST_ICONPLACE);
}


//---------------------------------------------------
//  TCustomFileSaveDialog::~TCustomFileSaveDialog()
//---------------------------------------------------
TCustomFileSaveDialog::~TCustomFileSaveDialog ()
{
	Destroy();

	delete pIcon;
	delete pBkBrush;
}


//----------------------------------------
//  TCustomFileSaveDialog::SetupWindow()
//----------------------------------------
void TCustomFileSaveDialog::SetupWindow()
{
	TRect WindowRect;
	int nXPos, nYPos;

	TFileSaveDialog::SetupWindow();

	// Hide Help button if necessary
	if (pHelpButton && !(Data.Flags & OFN_SHOWHELP))
	{
		pHelpButton->Show(SW_HIDE);
	}

	// Associate the icon with the Icon control
	if (pIcon)
		hOldIcon = (HICON)pIconPlace->SendMessage(STM_SETICON,
												   (WPARAM)(HICON)*pIcon,0L);
	// Center this window on the screen
	GetWindowRect(WindowRect);
	nXPos = (::GetSystemMetrics(SM_CXSCREEN) / 2) - (WindowRect.Width() / 2);
	nYPos = (::GetSystemMetrics(SM_CYSCREEN) / 2) - (WindowRect.Height() / 2);
	MoveWindow(nXPos,nYPos,WindowRect.Width(),WindowRect.Height(),FALSE);
}


//------------------------------------------
//  TCustomFileSaveDialog::CleanupWindow()
//------------------------------------------
void TCustomFileSaveDialog::CleanupWindow()
{
	// Restore the Icon control
	if (pIcon)
		pIconPlace->SendMessage(STM_SETICON,(WPARAM)hOldIcon,0L);

	TFileSaveDialog::CleanupWindow();
}


//---------------------------------------
//  TCustomFileSaveDialog::EvCtlColor()
//---------------------------------------
HBRUSH TCustomFileSaveDialog::EvCtlColor(HDC hDC,HWND hwndChild,UINT nCtlType)
{
	if (nCtlType == CTLCOLOR_LISTBOX)
		return *pBkBrush;
	else
		return TFileSaveDialog::EvCtlColor(hDC,hwndChild,nCtlType);
}



